@@ -3,13 +3,15 @@ from __future__ import annotations
 import copy
 from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Union
 
+from terra_proto.cosmos.base.v1beta1 import Coin as Coin_pb
+
 from terra_sdk.util.json import JSONSerializable
 
 from .coin import Coin
 from .numeric import Numeric
 
 
-class Coins(JSONSerializable):
+class Coins(JSONSerializable, List[Coin_pb]):
     """Represents an unordered collection of :class:`Coin` objects
     -- analagous to ``sdk.Coins`` and ``sdk.DecCoins`` in Cosmos SDK. If one of the
     input coins would be ``Dec``-amount type coin, the resultant Coins is converted to
@@ -113,9 +115,28 @@ class Coins(JSONSerializable):
         coins = map(Coin.from_data, data)
         return cls(coins)
 
+    def to_amino(self) -> List[dict]:
+        return [coin.to_amino() for coin in self]
+
     def to_data(self) -> List[dict]:
         return [coin.to_data() for coin in self]
 
+    @classmethod
+    def from_proto(cls, proto: List[Coin_pb]) -> Coins:
+        """Converts list of Coin-data objects to :class:`Coins`.
+
+        Args:
+            data (list): list of Coin-data objects
+        """
+        coins = map(Coin.from_proto, proto)
+        return cls(coins)
+
+    def to_proto(self) -> List[Coin_pb]:
+        return [coin.to_proto() for coin in self]
+
+    def to_dict(self) -> List[dict]:
+        return [coin.to_dict for coin in self]
+
     def denoms(self) -> List[str]:
         """Get the list of denoms for all Coin objects contained."""
         return [c.denom for c in self]
